@@ -1,3 +1,4 @@
+from collections.abc import Mapping
 from io import BytesIO
 from typing import Any, TypeVar, Union, cast
 
@@ -69,8 +70,8 @@ class BodyUploadFileProjectsProjectIdLocationsLocationIdMethodsMethodIdUploadPos
         return field_dict
 
     @classmethod
-    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
-        d = src_dict.copy()
+    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
+        d = dict(src_dict)
         file = File(payload=BytesIO(d.pop("file")))
 
         def _parse_comment(data: object) -> Union[None, Unset, str]:
